@@ -1,11 +1,8 @@
 package Dancer::Template::Caribou;
-BEGIN {
-  $Dancer::Template::Caribou::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $Dancer::Template::Caribou::VERSION = '0.1.1';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Template::Caribou wrapper for Dancer
+$Dancer::Template::Caribou::VERSION = '1.0.0';
+# TODO I think the template loading can be simplified
 
 use strict;
 use warnings;
@@ -80,11 +77,8 @@ package $name;
 use Moose::Role;
 use Template::Caribou;
 
-with 'Template::Caribou';
-
 with 'Template::Caribou::Files' => {
     dirs => [ '$bou_dir' ],
-    auto_reload => 1,
 };
 
 # line 1 "$bou"
@@ -116,11 +110,8 @@ sub generate_view_class {
     eval qq{
 package $name;
 
-use Moose;
 use Template::Caribou;
 
-with 'Template::Caribou';
-
 with 'Template::Caribou::Files' => {
     dirs => [ '$bou_dir' ],
     auto_reload => 1,
@@ -155,6 +146,9 @@ sub layout {
 sub render {
     my( $self, $template, $tokens ) = @_;
 
+    $DB::single = 1;
+    
+
     $template =~ s/\.bou$//;
 
     my $class = $self->view_class->{$template};
@@ -164,7 +158,7 @@ sub render {
       $c =~ s#/#::#g;
             $c = join '::', $self->namespace, $c;
           die "template '$template' not found\n"
-                unless eval { $c->DOES('Template::Caribou') };
+                unless eval { $c->DOES('Template::Caribou::Role') };
            $class = $c;
       }
 
@@ -197,13 +191,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dancer::Template::Caribou - Template::Caribou wrapper for Dancer
 
 =head1 VERSION
 
-version 0.1.1
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -301,11 +297,15 @@ above, we could change it into
 
 
     # in /views/howdie/page
-    html {
-        head { title { 'My App' } };
-        body {
-            h1 { 'howdie ' . $self->name . '!' };
-        };
+    sub {
+        my $self = shift;
+
+        html {
+            head { title { 'My App' } };
+            body {
+                h1 { 'howdie ' . $self->name . '!' };
+            };
+        }
     }
 
 =head3 Layouts as roles
@@ -323,11 +323,15 @@ the template class. Again, to take our example:
     # instead than in the 'bou' file 
     use Template::Caribou::Tags::HTML ':all';
 
-    html {
-        head { title { 'My App' } };
-        body {
-            show( 'inner' );
-        };
+    sub {
+        my $self = shift;
+
+        html {
+            head { title { 'My App' } };
+            body {
+                $self->inner_template;
+            };
+        }
     }
 
     # in /views/hullo/bou
@@ -337,7 +341,7 @@ the template class. Again, to take our example:
     has name => ( is => 'ro' );
 
     # in /views/howdie/inner
-    h1 { 'hullo ' . $self->name . '!' };
+    sub { my $self = shift; h1 { 'hullo ' . $self->name . '!' } }
 
 =head1 CONFIGURATION
 
@@ -348,12 +352,6 @@ the template class. Again, to take our example:
 The namespace under which the Caribou classes are created.
 defaults to C<Dancer::View>.
 
-=item auto_reload
-
-If set to C<true>, the Caribou object will verify if any of the 
-template files have changed before rendering and, if that's the case,
-will self-update. Defaults to C<false>.
-
 =back
 
 =head1 AUTHOR
